@@ -7,6 +7,8 @@ from carbon3d.api.attachments_api import AttachmentsApi
 from carbon3d.api.builds_api import BuildsApi
 from carbon3d.api.models_api import ModelsApi
 from carbon3d.api.orders_api import OrdersApi
+from carbon3d.api.part_measurement_templates_api import PartMeasurementTemplatesApi
+from carbon3d.api.part_measurements_api import PartMeasurementsApi
 from carbon3d.api.part_orders_api import PartOrdersApi
 from carbon3d.api.parts_api import PartsApi
 from carbon3d.api.print_orders_api import PrintOrdersApi
